# <span class="badge package-variant-panelcfg"></span> heatmap

## Objects

 * <span class="badge object-type-class"></span> [CellValues](./object-CellValues.md)
 * <span class="badge object-type-class"></span> [ExemplarConfig](./object-ExemplarConfig.md)
 * <span class="badge object-type-class"></span> [FieldConfig](./object-FieldConfig.md)
 * <span class="badge object-type-class"></span> [FilterValueRange](./object-FilterValueRange.md)
 * <span class="badge object-type-enum"></span> [HeatmapColorMode](./object-HeatmapColorMode.md)
 * <span class="badge object-type-class"></span> [HeatmapColorOptions](./object-HeatmapColorOptions.md)
 * <span class="badge object-type-enum"></span> [HeatmapColorScale](./object-HeatmapColorScale.md)
 * <span class="badge object-type-class"></span> [HeatmapLegend](./object-HeatmapLegend.md)
 * <span class="badge object-type-class"></span> [HeatmapTooltip](./object-HeatmapTooltip.md)
 * <span class="badge object-type-class"></span> [Options](./object-Options.md)
 * <span class="badge object-type-class"></span> [RowsHeatmapOptions](./object-RowsHeatmapOptions.md)
 * <span class="badge object-type-class"></span> [YAxisConfig](./object-YAxisConfig.md)
## Builders

 * <span class="badge builder"></span> [CellValues](./builder-CellValues.md)
 * <span class="badge builder"></span> [ExemplarConfig](./builder-ExemplarConfig.md)
 * <span class="badge builder"></span> [FilterValueRange](./builder-FilterValueRange.md)
 * <span class="badge builder"></span> [HeatmapColorOptions](./builder-HeatmapColorOptions.md)
 * <span class="badge builder"></span> [HeatmapLegend](./builder-HeatmapLegend.md)
 * <span class="badge builder"></span> [HeatmapTooltip](./builder-HeatmapTooltip.md)
 * <span class="badge builder"></span> [Panel](./builder-Panel.md)
 * <span class="badge builder"></span> [RowsHeatmapOptions](./builder-RowsHeatmapOptions.md)
 * <span class="badge builder"></span> [YAxisConfig](./builder-YAxisConfig.md)
## Functions

### <span class="badge function"></span> variant_config

variant_config returns the configuration related to heatmap panels.

This configuration describes how to unmarshal it, convert it to code, …

```python
def variant_config() -> variants.PanelcfgConfig
```

